==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IPFIXConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IPFIXConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.IPFIXConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.IPFIXConfigFluent<A>{
  public IPFIXConfigFluentImpl() {
  }
  public IPFIXConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.IPFIXConfig instance) {
    this.withCollectors(instance.getCollectors()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> collectors = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToCollectors(java.lang.Integer index,java.lang.String item) {
    if (this.collectors == null) {this.collectors = new java.util.ArrayList<java.lang.String>();}
    this.collectors.add(index, item);
    return (A)this;
  }
  public A setToCollectors(java.lang.Integer index,java.lang.String item) {
    if (this.collectors == null) {this.collectors = new java.util.ArrayList<java.lang.String>();}
    this.collectors.set(index, item); return (A)this;
  }
  public A addToCollectors(java.lang.String... items) {
    if (this.collectors == null) {this.collectors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.collectors.add(item);} return (A)this;
  }
  public A addAllToCollectors(java.util.Collection<java.lang.String> items) {
    if (this.collectors == null) {this.collectors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.collectors.add(item);} return (A)this;
  }
  public A removeFromCollectors(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.collectors!= null){ this.collectors.remove(item);}} return (A)this;
  }
  public A removeAllFromCollectors(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.collectors!= null){ this.collectors.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getCollectors() {
    return this.collectors;
  }
  public java.lang.String getCollector(java.lang.Integer index) {
    return this.collectors.get(index);
  }
  public java.lang.String getFirstCollector() {
    return this.collectors.get(0);
  }
  public java.lang.String getLastCollector() {
    return this.collectors.get(collectors.size() - 1);
  }
  public java.lang.String getMatchingCollector(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: collectors) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingCollector(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: collectors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCollectors(java.util.List<java.lang.String> collectors) {
    if (collectors != null) {this.collectors = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : collectors){this.addToCollectors(item);}} else { this.collectors = null;} return (A) this;
  }
  public A withCollectors(java.lang.String... collectors) {
    if (this.collectors != null) {this.collectors.clear();}
    if (collectors != null) {for (java.lang.String item :collectors){ this.addToCollectors(item);}} return (A) this;
  }
  public java.lang.Boolean hasCollectors() {
    return collectors != null && !collectors.isEmpty();
  }
  public A addNewCollector(java.lang.String arg0) {
    return (A)addToCollectors(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IPFIXConfigFluentImpl that = (IPFIXConfigFluentImpl) o;
    if (collectors != null ? !collectors.equals(that.collectors) :that.collectors != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(collectors,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/IPFIXConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IPFIXConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.IPFIXConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.IPFIXConfigFluent<A>{
  public IPFIXConfigFluentImpl() {
  }
  public IPFIXConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.IPFIXConfig instance) {
    this.withCollectors(instance.getCollectors()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> collectors = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToCollectors(java.lang.Integer index,java.lang.String item) {
    if (this.collectors == null) {this.collectors = new java.util.ArrayList<java.lang.String>();}
    this.collectors.add(index, item);
    return (A)this;
  }
  public A setToCollectors(java.lang.Integer index,java.lang.String item) {
    if (this.collectors == null) {this.collectors = new java.util.ArrayList<java.lang.String>();}
    this.collectors.set(index, item); return (A)this;
  }
  public A addToCollectors(java.lang.String... items) {
    if (this.collectors == null) {this.collectors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.collectors.add(item);} return (A)this;
  }
  public A addAllToCollectors(java.util.Collection<java.lang.String> items) {
    if (this.collectors == null) {this.collectors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.collectors.add(item);} return (A)this;
  }
  public A removeFromCollectors(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.collectors!= null){ this.collectors.remove(item);}} return (A)this;
  }
  public A removeAllFromCollectors(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.collectors!= null){ this.collectors.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getCollectors() {
    return this.collectors;
  }
  public java.lang.String getCollector(java.lang.Integer index) {
    return this.collectors.get(index);
  }
  public java.lang.String getFirstCollector() {
    return this.collectors.get(0);
  }
  public java.lang.String getLastCollector() {
    return this.collectors.get(collectors.size() - 1);
  }
  public java.lang.String getMatchingCollector(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: collectors) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingCollector(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: collectors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCollectors(java.util.List<java.lang.String> collectors) {
    if (collectors != null) {this.collectors = new java.util.ArrayList(); for (java.lang.String item : collectors){this.addToCollectors(item);}} else { this.collectors = null;} return (A) this;
  }
  public A withCollectors(java.lang.String... collectors) {
    if (this.collectors != null) {this.collectors.clear();}
    if (collectors != null) {for (java.lang.String item :collectors){ this.addToCollectors(item);}} return (A) this;
  }
  public java.lang.Boolean hasCollectors() {
    return collectors != null && !collectors.isEmpty();
  }
  public A addNewCollector(java.lang.String arg0) {
    return (A)addToCollectors(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IPFIXConfigFluentImpl that = (IPFIXConfigFluentImpl) o;
    if (collectors != null ? !collectors.equals(that.collectors) :that.collectors != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(collectors,  additionalProperties,  super.hashCode());
  }
  
}
